summaryrefslogtreecommitdiffstats
path: root/kjsembed/tools/headers/qbrush.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/tools/headers/qbrush.h')
-rw-r--r--kjsembed/tools/headers/qbrush.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/kjsembed/tools/headers/qbrush.h b/kjsembed/tools/headers/qbrush.h
index 16e4f3db..e85f0750 100644
--- a/kjsembed/tools/headers/qbrush.h
+++ b/kjsembed/tools/headers/qbrush.h
@@ -1,7 +1,7 @@
/****************************************************************************
**
**
** Definition of QBrush class
**
** Created : 940112
**
@@ -39,38 +39,38 @@
#define QBRUSH_H
#ifndef QT_H
-#include "qcolor.h"
-#include "qshared.h"
+#include "tqcolor.h"
+#include "tqshared.h"
#endif // QT_H
-class Q_EXPORT QBrush: public Qt
+class Q_EXPORT TQBrush: public Qt
{
friend class QPainter;
public:
- QBrush();
- QBrush( BrushStyle );
- QBrush( const QColor &, BrushStyle=SolidPattern );
- QBrush( const QColor &, const QPixmap & );
- QBrush( const QBrush & );
- ~QBrush();
- QBrush &operator=( const QBrush & );
+ TQBrush();
+ TQBrush( BrushStyle );
+ TQBrush( const TQColor &, BrushStyle=SolidPattern );
+ TQBrush( const TQColor &, const TQPixmap & );
+ TQBrush( const TQBrush & );
+ ~TQBrush();
+ TQBrush &operator=( const TQBrush & );
BrushStyle style() const { return data->style; }
void setStyle( BrushStyle );
- const QColor &color()const { return data->color; }
- void setColor( const QColor & );
- QPixmap *pixmap() const { return data->pixmap; }
- void setPixmap( const QPixmap & );
+ const TQColor &color()const { return data->color; }
+ void setColor( const TQColor & );
+ TQPixmap *pixmap() const { return data->pixmap; }
+ void setPixmap( const TQPixmap & );
- bool operator==( const QBrush &p ) const;
- bool operator!=( const QBrush &b ) const
+ bool operator==( const TQBrush &p ) const;
+ bool operator!=( const TQBrush &b ) const
{ return !(operator==(b)); }
private:
QBrush copy() const;
void detach();
- void init( const QColor &, BrushStyle );
+ void init( const TQColor &, BrushStyle );
struct QBrushData : public QShared { // brush data
BrushStyle style;
QColor color;
@@ -80,12 +80,12 @@ private:
/*****************************************************************************
- QBrush stream functions
+ TQBrush stream functions
*****************************************************************************/
#ifndef QT_NO_DATASTREAM
-Q_EXPORT QDataStream &operator<<( QDataStream &, const QBrush & );
-Q_EXPORT QDataStream &operator>>( QDataStream &, QBrush & );
+Q_EXPORT TQDataStream &operator<<( TQDataStream &, const TQBrush & );
+Q_EXPORT TQDataStream &operator>>( TQDataStream &, TQBrush & );
#endif
#endif // QBRUSH_H
@@ -1,7 +1,7 @@
**
**
-** Definition of QBrush class
+** Definition of TQBrush class
**
** Created : 940112